==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+54"/>
        <source>&amp;Layer</source>
        <translation>&amp;Layer</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+29"/>
        <source>Layer name:</source>
        <translation>Layername:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Lineweight:</source>
        <translation>Linienbreite:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Linetype:</source>
        <translation>Linientyp:</translation>
    </message>
    <message>
        <location line="-122"/>
        <source>Layer Data</source>
        <translation>Layer Data</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+136"/>
        <source>Leading or trailing spaces.</source>
        <translation>Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Layername ist leer.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Layer besteht schon.</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Layerwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Layerwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Layer</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+29"/>
        <source>Layer name:</source>
        <translation>Layername:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Stift</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Linienbreite:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Linientyp:</translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Layer Data</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Layername ist leer.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Layer besteht schon.</translation>
    </message>
</context>
</TS>
